capture log close
log using ers1-data-02-scale_creation, replace text

// Create Scales from Survey Questions, and Total Challenge and ScoreInc vars
// ERS1 - Escalation Study 1

version 13.1
clear all
macro drop _all
set more off
set linesize 80

local pgm "ers1-data-02-scale_creation"
local prj "Escalation Study 1"
local dte "2013-11-16"
local who "trenton mize"
local tag "`pgm' `who' `dte'"


use "- Data\ers1-02-clean-long", clear


******************************************************************
//  #1 - Create scales and calculate Cronbach's Alpha for Survey Measures
******************************************************************

* Baumeister Self-Regulation Questions
alpha 	SR*
egen 	SRscale2 = ///
		mean(SR1habits+SR2distract+SR3innap+SR4fun+SR5tempt+SR6disc+SR7pleas+ ///
		SR8regret+SR9stop+SR10act) ///
		, by(ID)
gen		SRscale = SRscale2/10		
lab var SRscale "Self-Regulation Scale"

* Honor Code Items
alpha 	HC*
egen 	HCscale2 = ///
		mean(HC11force+HC12tough+HC13even+HC14fair+HC15aggr+HC16intim) ///
		, by(ID)
gen		HCscale = HCscale2/6	
lab var HCscale "Honor Code Scale"


* Experience of Aggressive Interactions
alpha 	AG*
egen 	AGscale2 = ///
		mean(AG17angry+AG18crit+AG19face+AG20back+AG21insult+AG22shout+ ///
		AG23no+AG24hit+AG25slap+AG26obj) ///
		, by(ID)
gen		AGscale = AGscale2/10	
lab var AGscale "Aggression Scale"



******************************************************************
// #2 - Create sub-aggression scales
******************************************************************

tab1 AG*, m

* Verbal Perpetration
alpha 	AG19face AG22shout AG23no
egen 	AGscale_Verbal2 = mean(AG19face+AG22shout+AG23no) , by(ID)
gen		AGscale_Verbal = AGscale2/3	
lab var AGscale_Verbal "Verbal Aggression Scale"

*Physical Perpetration
alpha 	AG24hit AG25slap
egen 	AGscale_Phys2 = mean(AG24hit+AG25slap) , by(ID)
gen		AGscale_Phys = AGscale2/2	
lab var AGscale_Phys "Physical Aggression Scale"

* All Perpetration
alpha 	AG19face AG22shout AG23no AG24hit AG25slap
egen 	AGscale_Perp2 = mean(AG19face+AG22shout+AG23no+AG24hit+AG25slap) ///
		, by(ID)
gen		AGscale_Perp = AGscale2/5	
lab var AGscale_Perp "All Perpetration Aggression Scale"

* All Victimizations
alpha 	AG18crit AG20back AG21insult AG26obj
egen 	AGscale_Victim2 = mean(AG18crit+AG20back+AG21insult+AG26obj) , by(ID)
gen		AGscale_Victim = AGscale2/4	
lab var AGscale_Victim "All Victim of Aggression Scale"



******************************************************************
// #2b - Create Binary for Sub-Agression Items
******************************************************************

egen 		BAG_Verbal = total(AG19+AG22+AG23), by(ID)
lab var		BAG_Verbal "High Vebal Aggression"
tab			BAG_Verbal, m
recode		BAG_Verbal 6/14 = 1 	0/5 = 0
lab values 	BAG_Verbal yesno
tab 		BAG_Verbal, m

egen 		BAG_Physical = total(AG24hit+AG25slap), by(ID)
lab var		BAG_Physical "High Physical Aggression"
tab			BAG_Physical, m
recode		BAG_Physical 3/12 = 1 	0/2 = 0
lab values 	BAG_Physical yesno
tab 		BAG_Physical, m

egen 		BAG_Perp = total(AG19face+AG22shout+AG23no+AG24hit+AG25slap), by(ID)
lab var		BAG_Perp "High Perpetration"
tab			BAG_Perp, m
recode		BAG_Perp 8/26 = 1 	0/7 = 0
lab values 	BAG_Perp yesno
tab 		BAG_Perp, m

egen 		BAG_Victim = total(AG18crit+AG20back+AG21insult+AG26obj), by(ID)
lab var		BAG_Victim "High Victimization"
tab			BAG_Victim, m
recode		BAG_Victim 8/21 = 1 	0/7 = 0
lab values 	BAG_Victim yesno
tab 		BAG_Victim, m

tab1		BAG*, m



*Drop unneccessary vars
drop 	SRscale2 HCscale2 AGscale2 AGscale_Verbal2 AGscale_Phys2 ///
		AGscale_Perp2 AGscale_Victim2


*Save Data
compress
label 	data "ers1-03-w_scales.dta | Scales Created `prj' | `dte'"
note: 	ers1-03-w_scales-long | Scales Created | `tag'
datasignature set, reset
saveold "- Data\ers1-03-w_scales-long", replace



******************************************************************
// #4 - Create vars for total challenging and increasing competetive ability
		*In Wide Dataset
******************************************************************


/////////////////////////////////////////////////////////////////////////
//  Make a Wide Dataset and Save //
/////////////////////////////////////////////////////////////////////////
drop 	SRscale AGscale HCscale

reshape wide session roundscript lastact outcome ///
		reptotal reptotalA scoreinc challenge  ///
		latino race age yrschool major hicost ///
		female timeblk SR* HC* AG*, ///
		i(ID) j(period) 

**Resort alphabetically to drop unneccessary vars
aorder		
drop 	age1-age34 latino1-latino34 female1-female34  hicost1-hicost34 ///
		major1-major34 yrschool1-yrschool34 ///
		race1-race34 roundscript1-roundscript34 session1-session34  ///
		
		

egen	chaltot=rowtotal(challenge*)
lab var	chaltot "Challenge Total"
tab 	chaltot, m

egen	sinctot=rowtotal(scoreinc*)
lab var	sinctot "Score Inc Total"
tab		sinctot, m


clonevar	female_=female35
clonevar	hicost_=hicost35


**Save and Label Data

compress
label 	data "ers1-03-w_scales.dta | Scales Created `prj' | `dte'"
note: 	ers1-03-w_scales-wide | Scales Created | `tag'
datasignature set, reset
saveold "- Data\ers1-03-w_scales-wide", replace



log close
exit


NOTES:


**Self-Regulation**

Items        | S  it-cor  ir-cor   ii-cov   alpha   label
-------------+----------------------------------------------------------------
SR1habits35  | +   0.469   0.340   .20426   0.816   35 SR1habits
SR2distra~35 | +   0.481   0.353   .20305   0.815   35 SR2distract
SR3innap35   | +   0.629   0.490   .18114   0.803   35 SR3innap
SR4fun35     | -   0.700   0.593   .17648   0.790   35 SR4fun
SR5tempt35   | -   0.743   0.657   .17511   0.784   35 SR5tempt
SR6disc35    | -   0.557   0.434   .19448   0.807   35 SR6disc
SR7pleas35   | +   0.611   0.503   .19041   0.800   35 SR7pleas
SR8regret35  | +   0.671   0.571   .18355   0.793   35 SR8regret
SR9stop35    | +   0.704   0.610   .17978   0.789   35 SR9stop
SR10act35    | +   0.580   0.446   .18964   0.807   35 SR10act
-------------+----------------------------------------------------------------
Test scale   |                     .18779   0.817   mean(unstandardized items)
------------------------------------------------------------------------------


*****


**Honor Code**

Items        | S  it-cor  ir-cor   ii-cov   alpha   label
-------------+----------------------------------------------------------------
HC11force35  | +   0.675   0.559   .28129   0.811   35 HC11force
HC12tough35  | +   0.740   0.588   .24396   0.805   35 HC12tough
HC13even35   | +   0.738   0.609   .25381   0.799   35 HC13even
HC14fair35   | +   0.793   0.683   .23869   0.784   35 HC14fair
HC15aggr35   | +   0.800   0.676   .22792   0.784   35 HC15aggr
HC16intim35  | +   0.668   0.503   .26692   0.821   35 HC16intim
-------------+----------------------------------------------------------------
Test scale   |                      .2521   0.829   mean(unstandardized items)
------------------------------------------------------------------------------


*****


**Aggression Experience**

Items        | S  it-cor  ir-cor   ii-cov   alpha   label
-------------+----------------------------------------------------------------
AG17angry35  | +   0.537   0.441   .29281   0.799   35 AG17angry
AG18crit35   | +   0.599   0.505   .28244   0.793   35 AG18crit
AG19face35   | +   0.451   0.328   .29923   0.808   35 AG19face
AG20back35   | +   0.540   0.391   .27892   0.805   35 AG20back
AG21insult35 | +   0.839   0.745   .20939   0.757   35 AG21insult
AG22shout35  | +   0.772   0.647     .223   0.773   35 AG22shout
AG23no35     | +   0.673   0.551   .25542   0.785   35 AG23no
AG24hit35    | +   0.658   0.567   .27214   0.786   35 AG24hit
AG25slap35   | +   0.336   0.241   .31761   0.813   35 AG25slap
AG26obj35    | +   0.579   0.490   .28819   0.795   35 AG26obj
-------------+----------------------------------------------------------------
Test scale   |                     .27191   0.810   mean(unstandardized items)
------------------------------------------------------------------------------
